![Swamauri Logo](https://res.cloudinary.com/dbjmpekvl/image/upload/v1730099724/Swarmauri-logo-lockup-2048x757_hww01w.png)

<p align="center">
    <a href="https://pypi.org/project/swarmauri_middleware_exceptionhadling/">
        <img src="https://img.shields.io/pypi/dm/swarmauri_middleware_exceptionhadling" alt="PyPI - Downloads"/>
    </a>
    <a href="https://hits.sh/github.com/swarmauri/swarmauri-sdk/tree/master/pkgs/standards/swarmauri_middleware_exceptionhadling/">
        <img alt="Hits" src="https://hits.sh/github.com/swarmauri/swarmauri-sdk/tree/master/pkgs/standards/swarmauri_middleware_exceptionhadling.svg"/>
    </a>
    <a href="https://pypi.org/project/swarmauri_middleware_exceptionhadling/">
        <img src="https://img.shields.io/pypi/pyversions/swarmauri_middleware_exceptionhadling" alt="PyPI - Python Version"/>
    </a>
    <a href="https://pypi.org/project/swarmauri_middleware_exceptionhadling/">
        <img src="https://img.shields.io/pypi/l/swarmauri_middleware_exceptionhadling" alt="PyPI - License"/>
    </a>
    <a href="https://pypi.org/project/swarmauri_middleware_exceptionhadling/">
        <img src="https://img.shields.io/pypi/v/swarmauri_middleware_exceptionhadling?label=swarmauri_middleware_exceptionhadling&color=green" alt="PyPI - swarmauri_middleware_exceptionhadling"/>
    </a>
</p>

---

# Swarmauri Middleware Exceptionhadling

Middleware for handling exceptions and errors in Swarmauri applications.

## Installation

```bash
pip install swarmauri_middleware_exceptionhadling
```

## Want to help?

If you want to contribute to swarmauri-sdk, read up on our [guidelines for contributing](https://github.com/swarmauri/swarmauri-sdk/blob/master/contributing.md) that will help you get started.
